@@ -7,7 +7,7 @@
 ### by = "terms" calls directly permutest.cca which decomposes the
 ### inertia between successive terms within compiled C code.
 
-`anova.ccabyterm` <-
+`anovaCCAbyterm` <-
     function(object, permutations, model, parallel)
 {
     ## The result
@@ -50,7 +50,7 @@
 ## functions. Instead, we call ordConstrained with method="pass" with
 ## modified constraint matrix.
 
-`anova.ccabymargin` <-
+`anovaCCAbymargin` <-
     function(object, permutations, scope, ...)
 {
     EPS <- sqrt(.Machine$double.eps)
@@ -90,19 +90,26 @@
         stop("old style result object: update() your model")
     ## analyse only terms of 'ass' thar are in scope
     scopeterms <- which(alltrms %in% trmlab)
-    mods <- lapply(scopeterms, function(i, ...)
-           permutest(ordConstrained(Y, X[, ass != i, drop=FALSE], Z, "pass"),
-                     permutations, ...), ...)
+    mods <- suppressMessages(
+        lapply(scopeterms, function(i, ...)
+            permutest(ordConstrained(Y, X[, ass != i, drop = FALSE], Z, "pass"),
+                permutations, ...), ...)
+    )
     ## Chande in df
     Df <- sapply(mods, function(x) x$df[2]) - dfbig
     ## F of change
     Chisq <- sapply(mods, function(x) x$chi[2]) - chibig
     Fstat <- (Chisq/Df)/(chibig/dfbig)
     ## Simulated F-values
-    Fval <- sapply(mods, function(x) x$num)
-    ## Had we an empty model we need to clone the denominator
-    if (length(Fval) == 1)
-        Fval <- matrix(Fval, nrow = nperm)
+    Fval <- sapply(mods, function(x){
+        ## Get the permutation test results for a certain variable
+        temp <- x$num
+        ## If this variable did not explain any variance, no permutation test
+        ## was applied. In that case, give vector with zeroes.
+        if( x$nperm == 0 ) temp <- rep(0, nperm)
+        return(temp)
+        })
+    ## Calculate explained variance
     Fval <- sweep(-Fval, 1, big$num, "+")
     Fval <- sweep(Fval, 2, Df, "/")
     Fval <- sweep(Fval, 1, scale, "/")
@@ -145,7 +152,7 @@
 ### significance of axis k. My (J.Oksanen) simulations showed that
 ### this gave somewhat biased results.
 
-`anova.ccabyaxis` <-
+`anovaCCAbyaxis` <-
     function(object, permutations, model, parallel, cutoff = 1)
 {
     EPS <- sqrt(.Machine$double.eps)
@@ -197,7 +204,9 @@
     F.perm <- matrix(ncol = ncol(LC), nrow = nperm)
     for (i in seq_along(eig)) {
         if (i > 1) {
-            object <- ordConstrained(Y, X, cbind(Z, LC[, seq_len(i-1)]), "pass")
+            object <- suppressMessages(
+                ordConstrained(Y, X, cbind(Z, LC[, seq_len(i - 1)]), "pass")
+            )
         }
         if (length(eig) == i) {
             mod <- permutest(object, permutations, model = model,
@@ -207,8 +216,12 @@
                              parallel = parallel, first = TRUE)
         }
         Pvals[i] <- (sum(mod$F.perm >= mod$F.0 - EPS) + 1) / (nperm + 1)
+        ## follow Canoco: P-values of later axes cannot be lower than
+        ## previous axes (usually no effect as P-values are increasing).
+        if (i > 1 && Pvals[i] < Pvals[i-1])
+            Pvals[i] <- Pvals[i-1]
         F.perm[ , i] <- mod$F.perm
-        if (Pvals[i] > cutoff)
+        if (Pvals[i] >= cutoff)
             break
     }
     out <- data.frame(c(Df, resdf), c(eig, object$CA$tot.chi),
@@ -223,7 +236,7 @@
 
 ### Wrap permutest.cca(..., by="onedf") in a anova.cca form
 
-`anova.ccaby1df` <-
+`anovaCCAby1df` <-
     function(object, permutations, model, parallel)
 {
     ## Compute
