@@ -1,8 +1,10 @@
 `scores.ordiplot`  <-
     function (x, display = "sites", ...)
 {
-    if (length(x) == 1)
+    if (length(x) == 1) {
+        attr(x[[1]], "score") <- names(x)
         return(x[[1]])
+    }
     items <- names(x)
     items <- items[!is.na(items)]
     display <- match.arg(display, items)
