@@ -1,7 +1,7 @@
 `text.ordiplot`  <-
     function (x, what, labels, select, arrows = FALSE, length = 0.05, ...)
 {
-    sco <- scores(x, what)
+    sco <- scores(x, display = what)
     if (!missing(labels))
         rownames(sco) <- labels
     if (!missing(select))
@@ -13,7 +13,7 @@
     }
     if (arrows) {
         arrows(0, 0, sco[,1], sco[,2], length = length, ...)
-        sco <- ordiArrowTextXY(sco, rownames(sco), rescale = FALSE)
+        sco <- ordiArrowTextXY(sco, rownames(sco), rescale = FALSE, ...)
     }
     text(sco, labels = rownames(sco), ...)
     invisible(x)
