@@ -75,7 +75,7 @@ tolerance.cca <- function(x, choices = 1:2,
             ## avoid almost-1 for sites with only one spp
             N2[abs(N2-1) < ZAP] <- 1
             ## avoid "negative zeros" form 1 - 1/N2 when N2 ~ 1
-            res <- sweep(res, 1, sqrt(pmax(1 - 1/N2, 0)), "/")
+            res <- sweep(res, 1, sqrt(pmax.int(1 - 1/N2, 0)), "/")
         }
     } else {
         res <- matrix(ncol = length(choices), nrow = ncol(Y))
@@ -100,7 +100,7 @@ tolerance.cca <- function(x, choices = 1:2,
             ## avoid almost-1 for species present only once
             N2[abs(N2-1) < ZAP] <- 1
             ## avoid "negative zeros" form 1 - 1/N2 when N2 ~ 1
-            res <- sweep(res, 1, sqrt(pmax(1 - 1/N2, 0)), "/")
+            res <- sweep(res, 1, sqrt(pmax.int(1 - 1/N2, 0)), "/")
         }
     }
     res[!is.finite(res)] <- 0 # some values can be Inf or NaN but are really 0
