@@ -61,10 +61,10 @@
         site.ind <- site.ind[!is.na(site.ind)]
     }
     else {
-        stake <- colSums(x[site.ind, ]) > 0
+        stake <- colSums(x[site.ind,, drop = FALSE ]) > 0
     }
     sp.ind <- sp.ind[stake[sp.ind]]
-    x <- x[site.ind, sp.ind]
+    x <- x[site.ind, sp.ind, drop = FALSE]
     if (!missing(scale))
         x <- coverscale(x, scale, ...)
     usedscale <- attr(x, "scale")
@@ -75,6 +75,7 @@
     sp.nam <- rownames(x)
     sp.len <- max(nchar(sp.nam))
     nst <- ncol(x)
+    nlen <- max(nchar(colnames(x)))
     page.width <- getOption("width")
     per.page <- page.width - sp.len - 3
     istart <- seq(1, nst, by = per.page)
@@ -86,7 +87,6 @@
         tbl <- gsub("0", zero, tbl)
         tbl <- cbind(sp.nam, tbl)
         st.nam <- colnames(x)[istart[st]:iend[st]]
-        nlen <- max(nchar(st.nam))
         mathead <- matrix(" ", nrow = length(st.nam), ncol = nlen)
         for (i in seq_along(st.nam)) {
             tmp <- unlist(strsplit(st.nam[i], NULL))
@@ -103,8 +103,13 @@
         }
         dimnames(tbl) <- d
         print(noquote(tbl))
+        ## collect all pages for output table
+        if (exists(".tabout", inherits = FALSE))
+            .tabout[,2] <- paste0(.tabout[,2], tbl[,2])
+        else
+            .tabout <- tbl
     }
-    out <- list(sites = site.ind, species = sp.ind, table = tbl)
+    out <- list(sites = site.ind, species = sp.ind, table = .tabout)
     cat(length(out$sites), "sites,", length(out$species), "species\n")
     if (!is.null(usedscale))
         cat("scale: ",  usedscale, "\n")
